import typing
from System import Array_1
from System.Xml import XmlQualifiedName

class XmlSerializerNamespaces:
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, namespaces: XmlSerializerNamespaces) -> None: ...
    @typing.overload
    def __init__(self, namespaces: Array_1[XmlQualifiedName]) -> None: ...
    @property
    def Count(self) -> int: ...
    def Add(self, prefix: str, ns: str) -> None: ...
    def ToArray(self) -> Array_1[XmlQualifiedName]: ...

